@@ -48,7 +48,7 @@ static void gx_knob_size_request(GtkWidget *widget, gint *width, gint *height);
 static gboolean gx_knob_button_press(GtkWidget *widget, GdkEventButton *event);
 
 
-G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE(GxKnob, gx_knob, GX_TYPE_REGLER);
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE(GxKnob, gx_knob, GX_TYPE_REGLER)
 
 #define get_stock_id(widget) (GX_KNOB_CLASS(GTK_WIDGET_GET_CLASS(widget))->stock_id)
 
@@ -90,7 +90,7 @@ static void gx_knob_class_init(GxKnobClass *klass)
 		widget_class,
 		g_param_spec_int("y-center",
 		                    P_("Y-Center"),
-		                    P_("Verical position of the center, -1 for auto."),
+		                    P_("Vertical position of the center, -1 for auto."),
 		                    -1, 250, -1,
 		                    GParamFlags(G_PARAM_READABLE|G_PARAM_STATIC_STRINGS)));
     gtk_widget_class_install_style_property(
