@@ -25,7 +25,7 @@
 #include <lv2.h>
 
 #define GXPLUGIN_URI "http://guitarix.sourceforge.net/plugins/gx_hfb_"
-#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_hfb_gui"
+#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_hfb_gui#_hfb_"
 
 
 typedef enum
