@@ -25,7 +25,7 @@
 #include <lv2.h>
 
 #define GXPLUGIN_URI "http://guitarix.sourceforge.net/plugins/gx_hogsfoot_"
-#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_hogsfoot_gui"
+#define GXPLUGIN_UI_URI "http://guitarix.sourceforge.net/plugins/gx_hogsfoot_gui#_hogsfoot_"
 
 
 typedef enum
