@@ -23,11 +23,12 @@
 
 
 void _draw_label(void *w_, void* user_data) {
+    Metrics_t m;
+    int width, height;
     Widget_t *w = (Widget_t*)w_;
-    XWindowAttributes attrs;
-    XGetWindowAttributes(w->app->dpy, (Window)w->widget, &attrs);
-    int width = attrs.width;
-    int height = attrs.height;
+    os_get_window_metrics(w, &m);
+    width = m.width;
+    height = m.height;
 
     cairo_text_extents_t extents;
     use_text_color_scheme(w, get_color_state(w));
