@@ -28,7 +28,11 @@
 #include "valve.h"
 
 #include "gx_faust_plugins.h"
+#ifndef GUITARIX_AS_PLUGIN
 #include "../plugins/pluginlib.h"
+#else
+#include "pluginlib.h"
+#endif
 
 namespace gx_engine {
 
@@ -243,13 +247,11 @@ static int load_poweramp_ui(const UiBuilder& builder, int format) {
 	builder.closeBox();
 	builder.openHorizontalBox("");
 	{
-		builder.openVerticalBox("");
-		{
+		builder.create_mid_rackknob("poweramp.Pregain", _("Input"));
 	    builder.insertSpacer();
 	    builder.create_selector("poweramp.mode", _("Model"));
 	    builder.insertSpacer();
-	    }
-	    builder.closeBox();
+		builder.create_mid_rackknob("poweramp.Gain", _("Output"));
 	}
 	builder.closeBox();
 	return 0;
@@ -282,10 +284,13 @@ GxEngine::GxEngine(const string& plugin_dir, ParameterGroups& groups, const gx_s
 	  "poweramp.mode", _("select"),load_poweramp_ui , poweramp_groups, PGN_POST_PRE),
       // internal audio modules
       noisegate(),
+      outputgate(&noisegate),
       monomute(),
       stereomute(),
       tuner(*this),
+#ifndef GUITARIX_AS_PLUGIN
       drumout(),
+#endif
       directout(*this, sigc::mem_fun(mono_chain, &StereoModuleChain::sync)),
       maxlevel(),
       oscilloscope(*this),
@@ -296,10 +301,18 @@ GxEngine::GxEngine(const string& plugin_dir, ParameterGroups& groups, const gx_s
       preamp(*this, sigc::mem_fun(mono_chain, &MonoModuleChain::sync), resamp),
       preamp_st(*this, sigc::mem_fun(stereo_chain, &StereoModuleChain::sync), resamp),
       contrast(*this, sigc::mem_fun(mono_chain, &MonoModuleChain::sync), resamp),
-      loop(get_param(), sigc::mem_fun(mono_chain,&MonoModuleChain::sync),options.get_loop_dir()),
+      loop(get_param(), &directout, sigc::mem_fun(mono_chain,&MonoModuleChain::sync),options.get_loop_dir()),
+#ifndef GUITARIX_AS_PLUGIN
       record(*this, 1), record_st(*this, 2),
       dseq(*this, sigc::mem_fun(mono_chain, &MonoModuleChain::sync)),
-      detune(*this, sigc::mem_fun(mono_chain, &MonoModuleChain::sync)) {
+#endif
+      detune(*this, sigc::mem_fun(mono_chain, &MonoModuleChain::sync)),
+      neural_amp(get_param(), "nam", sigc::mem_fun(mono_chain,&MonoModuleChain::sync)),
+      sneural_amp(get_param(), "snam", sigc::mem_fun(mono_chain,&MonoModuleChain::sync)),
+      mneural_amp(get_param(), "mnam", sigc::mem_fun(mono_chain,&MonoModuleChain::sync)),
+      rtneural(get_param(), "rtneural", sigc::mem_fun(mono_chain,&MonoModuleChain::sync)),
+      srtneural(get_param(), "srtneural", sigc::mem_fun(mono_chain,&MonoModuleChain::sync)),
+      rtneuralmulti(get_param(), "mrtneural", sigc::mem_fun(mono_chain,&MonoModuleChain::sync)) {
     set_overload_interval(options.get_sporadic_overload());
     if (!options.get_convolver_watchdog()) {
         ov_disabled |= ov_Convolver;
@@ -370,7 +383,7 @@ void GxEngine::load_static_plugins() {
     pl.add(gx_effects::bassbooster::plugin(),     PLUGIN_POS_END, PGN_GUI|PGN_FIXED_GUI|PGN_POST);
     pl.add(gx_effects::gx_ampout::plugin(),       PLUGIN_POS_END, PGN_GUI|PGN_FIXED_GUI|PGN_POST);
     pl.add(&contrast.plugin,                      PLUGIN_POS_END, PGN_GUI|PGN_FIXED_GUI|PGN_POST);
-    pl.add(&noisegate.outputgate,                 PLUGIN_POS_END, PGN_POST);
+    pl.add(&outputgate.outputlevel,                 PLUGIN_POS_END, PGN_POST);
     pl.add(&monomute,                             PLUGIN_POS_END, PGN_POST|PGN_MODE_MUTE);
 
     // * amp insert position (stereo amp input) *
@@ -384,7 +397,9 @@ void GxEngine::load_static_plugins() {
     pl.add(&stereomute,                           PLUGIN_POS_END, PGN_MODE_MUTE);
     pl.add(fizz_remover::plugin(),                PLUGIN_POS_END, PGN_GUI);
     pl.add(hardlim::plugin(),                     PLUGIN_POS_END, PGN_MODE_NORMAL);
+#ifndef GUITARIX_AS_PLUGIN
     pl.add(&drumout.outputdrum,                   PLUGIN_POS_END, PGN_MODE_NORMAL);
+#endif
     pl.add(&directout,                            PLUGIN_POS_END, PGN_MODE_NORMAL);
     pl.add(&maxlevel,                             PLUGIN_POS_END, PGN_MODE_NORMAL|PGN_MODE_BYPASS);
 
@@ -406,9 +421,13 @@ void GxEngine::load_static_plugins() {
     pl.add(&poweramps.plugin,                     PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&wah.plugin,                           PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&loop.plugin,                          PLUGIN_POS_RACK, PGN_GUI);
+#ifndef GUITARIX_AS_PLUGIN
     pl.add(&record.plugin,                        PLUGIN_POS_RACK, PGN_GUI);
+#endif
     pl.add(&detune.plugin,                        PLUGIN_POS_RACK, PGN_GUI);
+#ifndef GUITARIX_AS_PLUGIN
     pl.add(&dseq.plugin,                          PLUGIN_POS_RACK, PGN_GUI);
+#endif
     pl.add(gx_effects::gx_distortion::plugin(),   PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::bitdowner::plugin(),       PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::thick_distortion::plugin(), PLUGIN_POS_RACK, PGN_GUI);
@@ -425,7 +444,9 @@ void GxEngine::load_static_plugins() {
     pl.add(gx_effects::delay::plugin(),           PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&mono_convolver.plugin,                PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::freeverb::plugin(),        PLUGIN_POS_RACK, PGN_GUI);
+#ifndef GUITARIX_AS_PLUGIN
     pl.add(&oscilloscope.plugin,                  PLUGIN_POS_RACK, PGN_GUI);
+#endif
     pl.add(gx_effects::biquad::plugin(),          PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::tremolo::plugin(),         PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::phaser_mono::plugin(),     PLUGIN_POS_RACK, PGN_GUI);
@@ -438,6 +459,12 @@ void GxEngine::load_static_plugins() {
     pl.add(&tonestack.plugin,                     PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&cabinet.plugin,                       PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&preamp.plugin,                        PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(&neural_amp.plugin,                    PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(&sneural_amp.plugin,                   PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(&mneural_amp.plugin,                   PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(&rtneural.plugin,                      PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(&srtneural.plugin,                     PLUGIN_POS_RACK, PGN_GUI);
+    pl.add(&rtneuralmulti.plugin,                 PLUGIN_POS_RACK, PGN_GUI);
     pl.add(pluginlib::abgate::plugin(),           PLUGIN_POS_RACK);
     pl.add(gx_effects::ring_modulator::plugin(),  PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::graphiceq::plugin(),       PLUGIN_POS_RACK, PGN_GUI);
@@ -449,7 +476,11 @@ void GxEngine::load_static_plugins() {
     pl.add(pluginlib::mbclipper::plugin(),        PLUGIN_POS_RACK, PGN_GUI);
     pl.add(pluginlib::bassboom::plugin(),         PLUGIN_POS_RACK, PGN_GUI);
     pl.add(pluginlib::mbchor::plugin(),           PLUGIN_POS_RACK, PGN_GUI);
+#ifndef DEBUG
+#ifndef GUITARIX_AS_PLUGIN
     pl.add(pluginlib::jcm800pre::plugin(),        PLUGIN_POS_RACK, PGN_GUI);
+#endif
+#endif
     pl.add(pluginlib::gcb_95::plugin(),           PLUGIN_POS_RACK, PGN_GUI);
 	pl.add(gx_effects::duck_delay::plugin(),      PLUGIN_POS_RACK, PGN_GUI);
 	pl.add(pluginlib::reversedelay::plugin(),     PLUGIN_POS_RACK, PGN_GUI);
@@ -472,7 +503,9 @@ void GxEngine::load_static_plugins() {
 	pl.add(pluginlib::rangem::plugin(),           PLUGIN_POS_RACK, PGN_GUI);
 	pl.add(pluginlib::ruin::plugin(),             PLUGIN_POS_RACK, PGN_GUI);
 	pl.add(pluginlib::ffreak::plugin(),           PLUGIN_POS_RACK, PGN_GUI);
+#ifndef GUITARIX_AS_PLUGIN
 	pl.add(pluginlib::fumaster::plugin(),         PLUGIN_POS_RACK, PGN_GUI);
+#endif
 	pl.add(pluginlib::fuzzdrive::plugin(),        PLUGIN_POS_RACK, PGN_GUI);
 	pl.add(pluginlib::rolandwah::plugin(),        PLUGIN_POS_RACK, PGN_GUI);
 	pl.add(pluginlib::astrofuzz::plugin(),        PLUGIN_POS_RACK, PGN_GUI);
@@ -495,7 +528,9 @@ void GxEngine::load_static_plugins() {
     pl.add(gx_effects::tonecontroll::plugin(),    PLUGIN_POS_RACK, PGN_GUI);
     pl.add(gx_effects::digital_delay_st::plugin(),PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&stereo_convolver.plugin,              PLUGIN_POS_RACK, PGN_GUI);
+#ifndef GUITARIX_AS_PLUGIN
     pl.add(&record_st.plugin,                     PLUGIN_POS_RACK, PGN_GUI);
+#endif
     pl.add(gx_effects::stereoverb::plugin(),      PLUGIN_POS_RACK, PGN_GUI);
     pl.add(pluginlib::zita_rev1::plugin(),        PLUGIN_POS_RACK);
     pl.add(pluginlib::vibe::plugin_stereo(),      PLUGIN_POS_RACK);
