@@ -26,7 +26,11 @@
 #include <bluetooth/rfcomm.h>
 #endif
 
+#ifndef GUITARIX_AS_PLUGIN
 #include "jsonrpc_methods.cc"
+#else
+#include "jsonrpc_methods-generated.cc"
+#endif
 
 const char *engine_state_to_string(gx_engine::GxEngineState s) {
     switch (s) {
@@ -120,13 +124,13 @@ void JsonArray::append(gx_system::JsonParser& jp) {
         push_back(new JsonString(jp.current_value()));
     } else if (jp.peek() == gx_system::JsonParser::value_number) {
         jp.next();
-        const char *str = jp.current_value().c_str();
+        std::string str = jp.current_value();
         char *endptr;
-        int n = strtol(str, &endptr, 10);
+        int n = strtol(str.c_str(), &endptr, 10);
         if (*endptr == '\0') {
             push_back(new JsonInt(n));
         } else {
-            istringstream b(str);
+            istringstream b(str.c_str());
             float f;
             b >> f;
             push_back(new JsonFloat(f));
@@ -630,6 +634,12 @@ void CmdConnection::call(gx_system::JsonWriter& jw, const methodnames *mn, JsonA
         jw.write(serv.jack.get_engine().controller_map.size());
     }
 
+    FUNCTION(get_midi_feedback) {
+        jw.begin_object();
+        jw.write(serv.settings.get_options().system_midiout);
+        jw.end_object();
+    }
+
     FUNCTION(getstate) {
         gx_engine::GxEngineState s = serv.jack.get_engine().get_state();
         jw.write(engine_state_to_string(s));
@@ -967,6 +977,10 @@ void CmdConnection::notify(gx_system::JsonStringWriter& jw, const methodnames *m
         serv.jack.get_engine().controller_map.set_last_midi_control_value(params[0]->getInt(),params[1]->getInt());
     }
 
+    PROCEDURE(set_midi_feedback) {
+        serv.settings.get_options().system_midiout = params[0]->getInt();
+    }
+
     PROCEDURE(set) {
         if (params.size() & 1) {
             throw RpcError(-32602, "Invalid param -- array length must be even");
@@ -2204,6 +2218,7 @@ bool GxService::idle_broadcast_handler() {
         broadcast_list.pop();
         usleep(2000);
     }
+    usleep(2000);
     return true;
 }
 
