@@ -25,8 +25,10 @@
 
 #include "guitarix.h"       // NOLINT
 
+#ifndef GUITARIX_AS_PLUGIN
 #include <gtkmm/main.h>     // NOLINT
 #include <gxwmm/init.h>     // NOLINT
+#endif
 #include <string>           // NOLINT
 #include <thread>
 
@@ -36,6 +38,23 @@
 #include "avahi_discover.h"
 #endif
 
+#ifdef GUITARIX_AS_PLUGIN
+#include <glibmm/init.h>
+
+volatile bool sInited = false;
+
+void run_mainloop() {
+	Glib::RefPtr<Glib::MainLoop> mainloop(Glib::MainLoop::create(/*Glib::MainContext::create()*/));
+	while (!sInited);
+	mainloop->run();
+}
+
+void gx_inited()
+{
+	sInited = true;
+}
+
+#else
 /****************************************************************
  ** class NsmSignals
  **
@@ -968,3 +987,4 @@ int main(int argc, char *argv[]) {
     }
     return 0;
 }
+#endif
