@@ -166,7 +166,7 @@ PresetWindow::PresetWindow(Glib::RefPtr<gx_gui::GxBuilder> bld, gx_engine::GxMac
     preset_column_preset->set_cell_data_func(
 	*preset_cellrenderer, sigc::mem_fun(*this, &PresetWindow::text_func));
 
-    // third colum
+    // third column
     banks_combobox->signal_changed().connect(
 	sigc::mem_fun(*this, &PresetWindow::on_preset_combo_changed));
     std::vector<Gtk::TargetEntry> listTargets3;
@@ -684,6 +684,7 @@ bool PresetWindow::on_bank_button_release(GdkEventButton *ev) {
     Glib::RefPtr<Gtk::ListStore> ls = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(bank_treeview->get_model());
     Gtk::TreeModel::iterator it = ls->get_iter(pt);
     Glib::ustring nm = it->get_value(bank_col.name);
+    if (nm.empty()) return false;
     int tp = it->get_value(bank_col.tp);
     if (col == bank_column_flags) {
 	if (tp == gx_system::PresetFile::PRESET_SCRATCH || tp == gx_system::PresetFile::PRESET_FILE) {
