@@ -18,18 +18,25 @@
 
 #include "guitarix.h"
 #include <sys/mman.h>
+#ifndef GUITARIX_AS_PLUGIN
 #include "jsonrpc_methods.h"
+#else
+#include "jsonrpc_methods-generated.h"
+#endif
 #include <netinet/in.h>
 #include <netinet/tcp.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <giomm/resolver.h>
+#include <giomm/inetsocketaddress.h>
 #ifdef HAVE_BLUEZ
 #include <bluetooth/bluetooth.h>
 #include <bluetooth/rfcomm.h>
 #endif
 
-#if !defined(__APPLE__) && !defined(__FreeBSD__)
+
+#if !defined(__APPLE__) && !defined(__FreeBSD__) && !defined(_WINDOWS)
 #include <malloc.h>
 
 void set_memory_allocation() {
@@ -48,6 +55,7 @@ void set_memory_allocation() {}
 #endif
 
 void lock_rt_memory() {
+#ifndef GUITARIX_AS_PLUGIN
 #ifndef __APPLE__
     extern char __rt_text__start[], __rt_text__end[];
     extern char __rt_data__start[], __rt_data__end[];
@@ -72,9 +80,11 @@ void lock_rt_memory() {
     fprintf(stderr,"mlock %ld bytes\n",total_size);
 #endif
 #endif
+#endif
 }
 
 void unlock_rt_memory() {
+#ifndef GUITARIX_AS_PLUGIN
 #ifndef __APPLE__    
     extern char __rt_text__start[], __rt_text__end[];
     extern char __rt_data__start[], __rt_data__end[];
@@ -98,6 +108,7 @@ void unlock_rt_memory() {
     fprintf(stderr,"munlock %ld bytes\n",total_size);
 #endif  
 #endif
+#endif
 }
 
 namespace gx_engine {
@@ -160,6 +171,7 @@ void on_engine_bypass_changed(bool s, GxEngine& engine) {
 }
 
 void GxMachine::process_cmdline_bank_preset() {
+#ifndef GUITARIX_AS_PLUGIN
     Glib::ustring sbank = options.get_setbank();
     if (sbank.empty()) {
         return;
@@ -174,6 +186,7 @@ void GxMachine::process_cmdline_bank_preset() {
     Glib::ustring preset = get_bank_file(bank)->get_name(
         KeySwitcher::key_offset_to_idx(std::stoi(sbank.substr(i))));
     options.set_bank_preset(bank, preset);
+#endif
 }
 
 GxMachine::GxMachine(gx_system::CmdlineOptions& options_):
@@ -267,9 +280,13 @@ GxMachine::GxMachine(gx_system::CmdlineOptions& options_):
       "engine.insert", N_("switch insert ports on/off"), (bool*)0, false, false)->getBool();
     ip.signal_changed().connect(
 	sigc::mem_fun(this, &GxMachineBase::set_jack_insert));
-
+#ifndef GUITARIX_AS_PLUGIN
+    pmap.reg_par("engine.set_stereo", N_("Stereo on/off"), (bool*)0, false, true);
+#endif
     gx_preset::UnitPresetList presetnames;
+#ifndef GUITARIX_AS_PLUGIN
     plugin_preset_list_load(pluginlist_lookup_plugin("seq")->get_pdef(), presetnames);
+#endif
     for (gx_preset::UnitPresetList::iterator i = presetnames.begin(); i != presetnames.end(); ++i) {
         if (!i->name.empty()) {
             Glib::ustring id = "seq." + i->name;
@@ -433,6 +450,15 @@ void GxMachine::commit_ladspa_changes() {
     }
 }
 
+#ifdef GUITARIX_AS_PLUGIN
+void GxMachine::timerUpdate() 
+{
+	if (engine.get_rack_changed())
+		if (!engine.check_module_lists())
+			engine.clear_rack_changed();
+	engine.signal_timeout().emit();
+}
+#endif
 sigc::signal<void,Plugin*,PluginChange::pc>& GxMachine::signal_plugin_changed() {
     return engine.signal_plugin_changed();
 }
@@ -442,7 +468,11 @@ Plugin *GxMachine::pluginlist_lookup_plugin(const std::string& id) const {
 }
 
 bool GxMachine::load_unit(gx_gui::UiBuilderImpl& builder, PluginDef* pdef) {
+#ifndef GUITARIX_AS_PLUGIN
     return builder.load_unit(pdef);
+#else
+    return false;
+#endif
 }
 
 void GxMachine::pluginlist_append_rack(UiBuilderBase& ui) {
@@ -623,13 +653,17 @@ Glib::ustring GxMachine::get_bank_name(int n) {
 }
 
 bool GxMachine::msend_midi_cc(int cc, int pgn, int bgn, int num) {
+#ifndef GUITARIX_AS_PLUGIN
 	return jack.send_midi_cc(cc, pgn, bgn, num);
+#else
+    return false;
+#endif
 }
 
 void GxMachine::load_preset(gx_system::PresetFileGui *pf, const Glib::ustring& name) {
-    int n = get_bank_index(get_current_bank());
     settings.load_preset(pf, name);
 #ifdef USE_MIDI_CC_OUT
+    int n = get_bank_index(get_current_bank());
     bool cc_ok = true;
     if (get_bank_index(pf->get_name()) != n) {
         cc_ok = msend_midi_cc(0xB0, 32, get_bank_index(pf->get_name()),3);
@@ -1107,13 +1141,14 @@ GxMachineRemote::GxMachineRemote(gx_system::CmdlineOptions& options_)
 	create_tcp_socket();
     }
     socket->set_blocking(true);
-    //writebuf = new __gnu_cxx::stdio_filebuf<char>(socket->get_fd(), std::ios::out);
+#ifdef GUITARIX_AS_PLUGIN
+    writebuf = new __gnu_cxx::stdio_filebuf<char>(socket->get_fd(), std::ios::out);
+    os = new ostream(writebuf);
+#else
     writebuf = new  boost::iostreams::file_descriptor_sink;
     writebuf->open(socket->get_fd(),boost::iostreams::never_close_handle);
-    
-    // os = new ostream(writebuf);
     os = new boost::iostreams::stream<boost::iostreams::file_descriptor_sink>(*writebuf);
-    
+#endif
     jw = new gx_system::JsonWriter(os, false);
 
     START_CALL(parameterlist);
@@ -1436,7 +1471,9 @@ void GxMachineRemote::handle_notify(gx_system::JsonStringParser *jp) {
     } else if (method == "plugins_changed") {
 	update_plugins(jp);
     } else if (method == "server_shutdown") {
+#ifndef GUITARIX_AS_PLUGIN
 	Gtk::Main::quit();
+#endif
     } else {
 	cerr << "> " << jp->get_string() << endl;
     }
@@ -1906,6 +1943,7 @@ int GxMachineRemote::load_remote_ui(const UiBuilder& builder, int form) {
 }
 
 bool GxMachineRemote::load_unit(gx_gui::UiBuilderImpl& builder, PluginDef* pdef) {
+#ifndef GUITARIX_AS_PLUGIN
     pdef->load_ui = [](const UiBuilder& builder, int form) {
                         GxMachineRemote *m = dynamic_cast<GxMachineRemote*>(
                             &static_cast<const gx_gui::UiBuilderImpl*>(
@@ -1913,6 +1951,9 @@ bool GxMachineRemote::load_unit(gx_gui::UiBuilderImpl& builder, PluginDef* pdef)
                         return m->load_remote_ui(builder, form);
                     };
     return builder.load_unit(pdef);
+#else
+    return false;
+#endif
 }
 
 
