@@ -82,10 +82,13 @@ public:
     ModuleSelectorFromList poweramps;
     // internal audio modules
     NoiseGate noisegate;
+    OutPutGate outputgate;
     MonoMute monomute;
     StereoMute stereomute;
     TunerAdapter tuner;
+#ifndef GUITARIX_AS_PLUGIN
     Drumout drumout;
+#endif
     Directout directout;
     MaxLevel maxlevel;
     OscilloscopeAdapter oscilloscope;
@@ -97,10 +100,18 @@ public:
     PreampStereoConvolver preamp_st;
     ContrastConvolver contrast;
     LiveLooper loop;
+#ifndef GUITARIX_AS_PLUGIN
     SCapture record;
     SCapture record_st;
     DrumSequencer dseq;
+#endif
     smbPitchShift detune;
+    NeuralAmp neural_amp;
+    NeuralAmp sneural_amp;
+    NeuralAmpMulti mneural_amp;
+    RtNeural rtneural;
+    RtNeural srtneural;
+    RtNeuralMulti rtneuralmulti;
     //
 public:
     GxEngine(const string& plugin_dir, ParameterGroups& groups, const gx_system::CmdlineOptions& options);
