@@ -321,6 +321,8 @@ public:
     std::string replace_symbol(const std::string& dir) const;
     std::string replace_path(const std::string& dir) const;
     void add(char s, const std::string& d);
+    void replace(char s, const std::string& d);
+    const symbol_path_map& get_symbol_path_map() { return dirs;}
 };
 
 
@@ -371,7 +373,12 @@ private:
 protected:
     static void make_ending_slash(std::string& dirpath);
 public:
+#ifdef GUITARIX_AS_PLUGIN
+    BasicOptions(const char *modulepath);
+    void replace_sysIRDir(const std::string& dir);
+#else
     BasicOptions();
+#endif
     ~BasicOptions();
     std::string get_user_filepath(const std::string& basename) const { return user_dir + basename; }
     std::string get_user_ir_filepath(const std::string& basename) const { return user_IR_dir + basename; }
@@ -468,7 +475,11 @@ public:
     bool reload_lv2_presets;
 
 public:
+#ifdef GUITARIX_AS_PLUGIN
+    CmdlineOptions(const char *modulepath);
+#else
     CmdlineOptions();
+#endif
     ~CmdlineOptions();
     void process(int argc, char** argv);
     const std::string& get_path_to_program() const { return path_to_program; }
