@@ -21,10 +21,14 @@
 #ifndef SRC_HEADERS_MACHINE_H_
 #define SRC_HEADERS_MACHINE_H_
 
-// #include <ext/stdio_filebuf.h>
+#ifndef GUITARIX_AS_PLUGIN
 #include <boost/iostreams/device/file_descriptor.hpp>
 #include <boost/iostreams/stream.hpp>
 #include "jsonrpc_methods.h"
+#else
+#include <ext/stdio_filebuf.h>
+#include "jsonrpc_methods-generated.h"
+#endif
 #ifdef HAVE_AVAHI
 #include "avahi_register.h"
 #endif
@@ -126,6 +130,7 @@ public:
     virtual void plugin_preset_list_save(const PluginDef *pdef, const Glib::ustring& name) = 0;
     virtual void plugin_preset_list_remove(const PluginDef *pdef, const Glib::ustring& name) = 0;
     virtual void disable_autosave(bool v) = 0;
+    virtual void disable_save_on_exit(bool v) = 0;
     virtual sigc::signal<void>& signal_selection_changed() = 0;
     virtual sigc::signal<void>& signal_presetlist_changed() = 0;
     virtual gx_system::PresetFileGui *bank_insert_uri(const Glib::ustring& uri, bool move, int position) = 0;
@@ -188,6 +193,8 @@ public:
     virtual int midi_param2controller(Parameter& param, const MidiController** p) = 0;
     virtual void set_midi_channel(int s) = 0;
     virtual void midi_feedback(int c, int v) = 0;
+    virtual bool get_midi_feedback() = 0;
+    virtual void set_midi_feedback(int v) = 0;
     virtual void on_tuner_freq_changed() = 0;
     // Convolver
     virtual void reload_impresp_list(const std::string& path) = 0;
@@ -266,6 +273,15 @@ public:
     virtual void load_ladspalist(std::vector<std::string>& old_not_found, ladspa::LadspaPluginList& pluginlist);
     virtual void save_ladspalist(ladspa::LadspaPluginList& pluginlist);
     virtual void commit_ladspa_changes();
+
+#ifdef GUITARIX_AS_PLUGIN
+	gx_preset::GxSettings& get_settings() {return settings;}
+
+	void timerUpdate();
+    void start_ramp_down() { engine.start_ramp_down(); }
+    void wait_ramp_down_finished() { engine.wait_ramp_down_finished(); }
+    void start_ramp_up() {engine.start_ramp_up();}
+#endif
     virtual sigc::signal<void,Plugin*,PluginChange::pc>& signal_plugin_changed();
     virtual Plugin *pluginlist_lookup_plugin(const std::string& id) const;
     virtual bool load_unit(gx_gui::UiBuilderImpl& builder, PluginDef* pdef);
@@ -315,6 +331,7 @@ public:
     virtual void plugin_preset_list_save(const PluginDef *pdef, const Glib::ustring& name);
     virtual void plugin_preset_list_remove(const PluginDef *pdef, const Glib::ustring& name);
     virtual void disable_autosave(bool v);
+    virtual void disable_save_on_exit(bool v);
     virtual sigc::signal<void>& signal_selection_changed();
     virtual sigc::signal<void>& signal_presetlist_changed();
     virtual gx_system::PresetFileGui *bank_insert_uri(const Glib::ustring& uri, bool move, int position);
@@ -375,6 +392,8 @@ public:
     virtual int midi_param2controller(Parameter& param, const MidiController** p);
     virtual void set_midi_channel(int s);
     virtual void midi_feedback(int c, int v);
+    virtual bool get_midi_feedback();
+    virtual void set_midi_feedback(int v);
     virtual void on_tuner_freq_changed();
     // Convolver
     virtual void reload_impresp_list(const std::string& path);
@@ -393,10 +412,13 @@ private:
     sigc::signal<void> selection_changed;
     sigc::signal<void> presetlist_changed;
     Glib::RefPtr<Gio::Socket> socket;
-    // __gnu_cxx::stdio_filebuf<char> *writebuf;
+#ifdef GUITARIX_AS_PLUGIN
+    __gnu_cxx::stdio_filebuf<char> *writebuf;
+    ostream *os;
+#else
     boost::iostreams::file_descriptor_sink *writebuf;
-    // ostream *os;
     boost::iostreams::stream<boost::iostreams::file_descriptor_sink> *os;    
+#endif
     gx_system::JsonWriter *jw;
     std::vector<gx_system::JsonStringParser*> notify_list;
     sigc::connection idle_conn;
@@ -499,6 +521,7 @@ public:
     virtual void plugin_preset_list_save(const PluginDef *pdef, const Glib::ustring& name);
     virtual void plugin_preset_list_remove(const PluginDef *pdef, const Glib::ustring& name);
     virtual void disable_autosave(bool v);
+    virtual void disable_save_on_exit(bool v);
     virtual sigc::signal<void>& signal_selection_changed();
     virtual sigc::signal<void>& signal_presetlist_changed();
     virtual gx_system::PresetFileGui *bank_insert_uri(const Glib::ustring& uri, bool move, int position);
@@ -559,6 +582,8 @@ public:
     virtual int midi_param2controller(Parameter& param, const MidiController** p);
     virtual void set_midi_channel(int s);
     virtual void midi_feedback(int c, int v);
+    virtual bool get_midi_feedback();
+    virtual void set_midi_feedback(int v);
     virtual void on_tuner_freq_changed();
     // Convolver
     virtual void reload_impresp_list(const std::string& path);
