@@ -70,12 +70,12 @@ def parse_vars(items):
 
 os.chdir("../")
 
-comandline = "\n\n/*******************************************************************************\n"
-comandline += "**************************** File generated by *********************************\n"
-comandline += "********************************************************************************\n"
+commandline = "\n\n/*******************************************************************************\n"
+commandline += "**************************** File generated by *********************************\n"
+commandline += "********************************************************************************\n"
 for arg in sys.argv:
-    comandline += " %s" % arg
-comandline += "\n*******************************************************************************/\n\n"
+    commandline += " %s" % arg
+commandline += "\n*******************************************************************************/\n\n"
 
 del sys.argv[1:]
 from analog import *
@@ -333,7 +333,7 @@ class Generators(object):
                 fdata += process_line
         if(faust_table):
             fdata = fdata.replace('import("stdfaust.lib");', 'import("stdfaust.lib");\n%s') % faust_table_template
-        fdata = comandline + fdata
+        fdata = commandline + fdata
         with open(dspfile, 'w') as f:
             f.write(fdata)
         f.close()
@@ -638,7 +638,7 @@ class DKbuilder(object):
                                 faustdsp +=  '\n    {st}p = ffunction(float {st}clip(float), "{st}_table.h", "");\n'.format(st=self.tablename[dsp_counter-1])
                                 faustdsp += '\n    {st}_clip = freq_split: ( {st}p , {st}p , {st}p, {st}p, {st}p) :>_;\n'.format(st=self.tablename[dsp_counter-1])
                             else:
-                                faustdsp +=  '\n    {st}p = ffunction(float {st}clip(float), "{st}_table.h", "");\n'.format(st=self.tablename[dsp_counter-1])
+                                faustdsp +=  '\n    {st}_clip = ffunction(float {st}clip(float), "{st}_table.h", "");\n'.format(st=self.tablename[dsp_counter-1])
                 else:
                     faustdsp = faustdsp.replace('//TABLE', '\n\n%s') % dlimer
                 faustdsp = faustdsp.replace('process', "p%s" % dsp_counter)
