@@ -168,9 +168,17 @@ def configure(conf):
             conf.env['OPT'] = False
             cpu_model = append_optimization_flags(conf, cxxflags)
 
-    if '-flto' in cxxflags:
+    if any(x.startswith('-flto') for x in cxxflags):
+        conf.env['LTO'] = True
         cxxflags.append ("-ffat-lto-objects")
 
-    cxxflags.append ("-std=c++11")
+    cxxflags.append ("-std=c++17")
+   # cxxflags.append ("-Ofast")
+    cxxflags.append ("-DDSP_SAMPLE_FLOAT")
+    cxxflags.append ("-DNAM_SAMPLE_FLOAT")
+    cxxflags.append ("-Dneural_amp_modeler_EXPORTS")
+    cxxflags.append ("-DRTNEURAL_DEFAULT_ALIGNMENT=32")
+    cxxflags.append ("-DRTNEURAL_USE_EIGEN=1")
+    cxxflags.append ("-DRTNEURAL_NAMESPACE=RTNeural")
     conf.env['CXXFLAGS'] += cxxflags
     conf.cpu_model = cpu_model
